%
%  Construct a matrix K, such that (roughly)  
% 
%      K*sigma=[vdata; hdata]'
%
%  K=makek(layer,vheight,hheight)
%
%  Input:
%    layer     layer(i) gives the depth of the ith layer.
%    vheight   heights of vertical measurements
%    hheight   heights of horizontal measurements.
%
%  Output:
%    K         The matrix for the discrete version of the problem.  
%
%
function K=makek(layer,vheight,hheight)

for i=1:length(vheight),
  for j=1:length(layer)+1,
    if (j == 1),
      av(i,j)=rv(vheight(i))-rv(layer(j)+vheight(i));
    elseif (j == length(layer)+1),
      av(i,j)=rv(layer(j-1)+vheight(i));
    else
      av(i,j)=rv(layer(j-1)+vheight(i))-rv(layer(j)+vheight(i));
    end;
  end;
end;

for i=1:length(hheight),
  for j=1:length(layer)+1,
    if (j == 1),
      ah(i,j)=rh(hheight(i))-rh(layer(j)+hheight(i));
    elseif (j == length(layer)+1),
      ah(i,j)=rh(layer(j-1)+hheight(i));
    else
      ah(i,j)=rh(layer(j-1)+hheight(i))-rh(layer(j)+hheight(i));
    end;
  end;
end;

K=[av ; ah];



