%
%  plotsol(mdepth,mcond,layer,sigma)
%
%  Plot a pair of solutions.  to the inverse problem.
%    mdepth         depth at which measurements were taken.  
%    mcond          measured conductivities
%    layer          layer's in the discrete model.
%    sigma          conductivities in the discrete model.
%
function plotsol(mdepth,mcond,layer,sigma)
%
%  first, plot the measured conductivity profile.
%
hold off;
axis([0 400 0 1.6]);
h=gca;
set(h,'box','on')
set(h,'Ydir','reverse');
xlabel('Conductivity (mS/m)');
ylabel('Depth (m)');
hold on
plot(mcond,mdepth,'--');
plot(mcond,mdepth,'o');
%
%  Now, plot the estimated conductivity profile.
%
n=max(size(layer));
depth(1)=0;
cond(1)=sigma(1);
for i=1:n,
  depth(2*i)=layer(i);
  cond(2*i)=sigma(i);
  depth(2*i+1)=layer(i);
  cond(2*i+1)=sigma(i+1);
end;
depth(2*n+2)=max([max(mdepth),layer(n)+(layer(n)-layer(n-1))]);
cond(2*n+2)=sigma(n+1);
plot(cond,depth);

